@@ -1,7 +1,7 @@
 package Grizzly;
 # ABSTRACT: Grizzly - A command-line interface for looking up stock quote.
 
-our $VERSION = '0.002';
+our $VERSION = '0.100';
 
 use strict;
 use warnings;
@@ -25,6 +25,8 @@ Grizzly will output the stock quote of the given symbol.
 
     Options:
 
+    news [stock symbol]
+
     quote [stock symbol]
 
     help
@@ -33,12 +35,18 @@ Grizzly will output the stock quote of the given symbol.
 
 =head2 Options
 
+news - Displays the stock news of a given symbol.
+
 quote - Displays the stock quote of a given symbol.
 
 help - Displays a help message on how to use Grizzly.
 
 version - Displays Grizzly's version number.
 
+=head1 API Key
+
+You will need to get a free API key from L<NewsAPI|https://newsapi.org/>. Afterwards you will need to set the NEWS_API_KEY environment variable to the API key.
+
 =head1 AUTHOR
 
 Nobunaga <nobunaga@cpan.org>
